@@ -85,7 +85,72 @@ from .objects import (AccessPoint, ActiveConnection, ActiveVPNConnection,
                       NetworkManager, NetworkManagerAgentManager,
                       NetworkManagerDnsManager, NetworkManagerSettings,
                       WiFiP2PPeer)
-
+from .exceptions import (
+    NetworkManagerBaseError,
+    NmAgentManagerFailedError,
+    NmAgentManagerPermissionDeniedError,
+    NmAgentManagerInvalidIdentifierError,
+    NmAgentManagerNotRegisteredError,
+    NmAgentManagerNoSecretsError,
+    NmAgentManagerUserCanceledError,
+    NmConnectionFailedError,
+    NmConnectionSettingNotFoundError,
+    NmConnectionPropertyNotFoundError,
+    NmConnectionPropertyNotSecretError,
+    NmConnectionMissingSettingError,
+    NmConnectionInvalidSettingError,
+    NmConnectionMissingPropertyError,
+    NmConnectionInvalidPropertyError,
+    NmDeviceFailedError,
+    NmDeviceCreationFailedError,
+    NmDeviceInvalidConnectionError,
+    NmDeviceIncompatibleConnectionError,
+    NmDeviceNotActiveError,
+    NmDeviceNotSoftwareError,
+    NmDeviceNotAllowedError,
+    NmDeviceSpecificObjectNotFoundError,
+    NmDeviceVersionIdMismatchError,
+    NmDeviceMissingDependenciesError,
+    NmDeviceInvalidArgumentError,
+    NetworkManagerFailedError,
+    NetworkManagerPermissionDeniedError,
+    NetworkManagerUnknownConnectionError,
+    NetworkManagerUnknownDeviceError,
+    NetworkManagerConnectionNotAvailableError,
+    NetworkManagerConnectionNotActiveError,
+    NetworkManagerConnectionAlreadyActiveError,
+    NetworkManagerDependencyFailedError,
+    NetworkManagerAlreadyAsleepOrAwakeError,
+    NetworkManagerAlreadyEnabledOrDisabledError,
+    NetworkManagerUnknownLogLevelError,
+    NetworkManagerUnknownLogDomainError,
+    NetworkManagerInvalidArgumentsError,
+    NetworkManagerMissingPluginError,
+    NmSecretManagerFailedError,
+    NmSecretManagerPermissionDeniedError,
+    NmSecretManagerInvalidConnectionError,
+    NmSecretManagerUserCanceledError,
+    NmSecretManagerAgentCanceledError,
+    NmSecretManagerNoSecretsError,
+    NmSettingsFailedError,
+    NmSettingsPermissionDeniedError,
+    NmSettingsNotSupportedError,
+    NmSettingsInvalidConnectionError,
+    NmSettingsReadOnlyConnectionError,
+    NmSettingsUuidExistsError,
+    NmSettingsInvalidHostnameError,
+    NmSettingsInvalidArgumentsError,
+    NmVpnPluginFailedError,
+    NmVpnPluginStartingInProgressError,
+    NmVpnPluginAlreadyStartedError,
+    NmVpnPluginStoppingInProgressError,
+    NmVpnPluginAlreadyStoppedError,
+    NmVpnPluginWrongStateError,
+    NmVpnPluginBadArgumentsError,
+    NmVpnPluginLaunchFailedError,
+    NmVpnPluginInvalidConnectionError,
+    NmVpnPluginInteractiveNotSupportedError,
+)
 
 DEVICE_TYPE_TO_CLASS = {
     DeviceType.ETHERNET: NetworkDeviceWired,
@@ -192,4 +257,69 @@ __all__ = (
     'ConfigCheckpoint',
 
     'DEVICE_TYPE_TO_CLASS',
+
+    'NetworkManagerBaseError',
+    'NmAgentManagerFailedError',
+    'NmAgentManagerPermissionDeniedError',
+    'NmAgentManagerInvalidIdentifierError',
+    'NmAgentManagerNotRegisteredError',
+    'NmAgentManagerNoSecretsError',
+    'NmAgentManagerUserCanceledError',
+    'NmConnectionFailedError',
+    'NmConnectionSettingNotFoundError',
+    'NmConnectionPropertyNotFoundError',
+    'NmConnectionPropertyNotSecretError',
+    'NmConnectionMissingSettingError',
+    'NmConnectionInvalidSettingError',
+    'NmConnectionMissingPropertyError',
+    'NmConnectionInvalidPropertyError',
+    'NmDeviceFailedError',
+    'NmDeviceCreationFailedError',
+    'NmDeviceInvalidConnectionError',
+    'NmDeviceIncompatibleConnectionError',
+    'NmDeviceNotActiveError',
+    'NmDeviceNotSoftwareError',
+    'NmDeviceNotAllowedError',
+    'NmDeviceSpecificObjectNotFoundError',
+    'NmDeviceVersionIdMismatchError',
+    'NmDeviceMissingDependenciesError',
+    'NmDeviceInvalidArgumentError',
+    'NetworkManagerFailedError',
+    'NetworkManagerPermissionDeniedError',
+    'NetworkManagerUnknownConnectionError',
+    'NetworkManagerUnknownDeviceError',
+    'NetworkManagerConnectionNotAvailableError',
+    'NetworkManagerConnectionNotActiveError',
+    'NetworkManagerConnectionAlreadyActiveError',
+    'NetworkManagerDependencyFailedError',
+    'NetworkManagerAlreadyAsleepOrAwakeError',
+    'NetworkManagerAlreadyEnabledOrDisabledError',
+    'NetworkManagerUnknownLogLevelError',
+    'NetworkManagerUnknownLogDomainError',
+    'NetworkManagerInvalidArgumentsError',
+    'NetworkManagerMissingPluginError',
+    'NmSecretManagerFailedError',
+    'NmSecretManagerPermissionDeniedError',
+    'NmSecretManagerInvalidConnectionError',
+    'NmSecretManagerUserCanceledError',
+    'NmSecretManagerAgentCanceledError',
+    'NmSecretManagerNoSecretsError',
+    'NmSettingsFailedError',
+    'NmSettingsPermissionDeniedError',
+    'NmSettingsNotSupportedError',
+    'NmSettingsInvalidConnectionError',
+    'NmSettingsReadOnlyConnectionError',
+    'NmSettingsUuidExistsError',
+    'NmSettingsInvalidHostnameError',
+    'NmSettingsInvalidArgumentsError',
+    'NmVpnPluginFailedError',
+    'NmVpnPluginStartingInProgressError',
+    'NmVpnPluginAlreadyStartedError',
+    'NmVpnPluginStoppingInProgressError',
+    'NmVpnPluginAlreadyStoppedError',
+    'NmVpnPluginWrongStateError',
+    'NmVpnPluginBadArgumentsError',
+    'NmVpnPluginLaunchFailedError',
+    'NmVpnPluginInvalidConnectionError',
+    'NmVpnPluginInteractiveNotSupportedError',
 )
